import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/access_management/manage_bookable_spaces/domain/models/bookable_space_model.dart';
import 'package:syncrow_web/pages/access_management/manage_bookable_spaces/domain/params/non_bookable_spaces_params.dart';
import 'package:syncrow_web/pages/access_management/manage_bookable_spaces/presentation/blocs/non_bookable_spaces_bloc/non_bookaable_spaces_bloc.dart';
import 'package:syncrow_web/pages/access_management/manage_bookable_spaces/presentation/widgets/search_unbookable_spaces_widget.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class SpacesStepDetailsWidget extends StatelessWidget {
  SpacesStepDetailsWidget({
    super.key,
  });
  Timer? _debounce;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<NonBookableSpacesBloc, NonBookableSpacesState>(
      builder: (context, state) {
        if (state is NonBookableSpacesLoading) {
          return const Center(child: CircularProgressIndicator());
        } else if (state is NonBookableSpacesError) {
          return Text(state.error);
        } else if (state is NonBookableSpacesLoaded) {
          return Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Text(
                'Select Space',
                style: TextStyle(
                  fontWeight: FontWeight.w700,
                  color: ColorsManager.blackColor,
                ),
              ),
              const SizedBox(
                height: 20,
              ),
              Container(
                width: 450,
                height: 480,
                decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.circular(20),
                  boxShadow: const [
                    BoxShadow(
                      color: Color(0x40000000),
                      offset: Offset(0, 4),
                      blurRadius: 5,
                    ),
                  ],
                ),
                child: Column(
                  children: [
                    Container(
                      width: 520,
                      height: 70,
                      padding: const EdgeInsets.symmetric(
                          vertical: 15, horizontal: 20),
                      decoration: const BoxDecoration(
                        color: Color(0xFFF8F8F8),
                        borderRadius: BorderRadius.vertical(
                          top: Radius.circular(20),
                        ),
                      ),
                      child: SearchUnbookableSpacesWidget(
                        title: 'Search',
                        onChanged: (p0) {
                          if (_debounce?.isActive ?? false) _debounce!.cancel();
                          _debounce =
                              Timer(const Duration(milliseconds: 500), () {
                            context.read<NonBookableSpacesBloc>().add(
                                  LoadUnBookableSpacesEvent(
                                    nonBookableSpacesParams:
                                        NonBookableSpacesParams(
                                      currentPage: 1,
                                      searchedWords: p0,
                                    ),
                                  ),
                                );
                          });
                        },
                      ),
                    ),
                    Expanded(
                      child: Container(
                        width: 490,
                        decoration: const BoxDecoration(
                          color: Colors.white,
                          borderRadius: BorderRadius.vertical(
                            bottom: Radius.circular(20),
                          ),
                        ),
                        padding:
                            const EdgeInsets.only(top: 10, left: 20, bottom: 5),
                        child: ListView.separated(
                          separatorBuilder: (context, index) => const SizedBox(
                            height: 5,
                          ),
                          itemCount: state.nonBookableSpaces.data.length,
                          itemBuilder: (context, index) => CheckBoxSpaceWidget(
                            nonBookableSpace:
                                state.nonBookableSpaces.data[index],
                          ),
                        ),
                      ),
                    )
                  ],
                ),
              )
            ],
          );
        } else {
          return const SizedBox();
        }
      },
    );
  }
}

class CheckBoxSpaceWidget extends StatefulWidget {
  final BookableSpacemodel nonBookableSpace;

  const CheckBoxSpaceWidget({
    super.key,
    required this.nonBookableSpace,
  });

  @override
  State<CheckBoxSpaceWidget> createState() => _CheckBoxSpaceWidgetState();
}

class _CheckBoxSpaceWidgetState extends State<CheckBoxSpaceWidget> {
  bool isChecked = false;

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Checkbox(
          value: isChecked,
          onChanged: (value) => setState(() {
            isChecked = value ?? false;
            if (isChecked) {
              context.read<NonBookableSpacesBloc>().add(
                    AddToBookableSpaceEvent(
                      nonBookableSpace: widget.nonBookableSpace,
                    ),
                  );
            } else {
              context.read<NonBookableSpacesBloc>().add(
                    RemoveFromBookableSpaceEvent(
                      bookableSpace: widget.nonBookableSpace,
                    ),
                  );
            }
          }),
        ),
        const SizedBox(
          width: 5,
        ),
        Text(widget.nonBookableSpace.spaceName),
      ],
    );
  }
}
